@@ -1,8 +1,9 @@
-/* Copyright 2003-2004 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -149,9 +150,9 @@ typedef apr_uint64_t sha2_word64;       /* Exactly 8 bytes */
  * library -- they are intended for private internal visibility/use
  * only.
  */
-void SHA512_Last(SHA512_CTX*);
-void SHA256_Transform(SHA256_CTX*, const sha2_word32*);
-void SHA512_Transform(SHA512_CTX*, const sha2_word64*);
+void apr__SHA512_Last(SHA512_CTX*);
+void apr__SHA256_Transform(SHA256_CTX*, const sha2_word32*);
+void apr__SHA512_Transform(SHA512_CTX*, const sha2_word64*);
 
 
 /*** SHA-XYZ INITIAL HASH VALUES AND CONSTANTS ************************/
@@ -263,7 +264,7 @@ static const char *sha2_hex_digits = "0123456789abcdef";
 
 
 /*** SHA-256: *********************************************************/
-void SHA256_Init(SHA256_CTX* context) {
+void apr__SHA256_Init(SHA256_CTX* context) {
         if (context == (SHA256_CTX*)0) {
                 return;
         }
@@ -309,7 +310,7 @@ void SHA256_Init(SHA256_CTX* context) {
         (h) = T1 + Sigma0_256(a) + Maj((a), (b), (c)); \
         j++
 
-void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
+void apr__SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
         sha2_word32     a, b, c, d, e, f, g, h, s0, s1;
         sha2_word32     T1, *W256;
         int             j;
@@ -367,7 +368,7 @@ void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
 
 #else /* SHA2_UNROLL_TRANSFORM */
 
-void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
+void apr__SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
         sha2_word32     a, b, c, d, e, f, g, h, s0, s1;
         sha2_word32     T1, T2, *W256;
         int             j;
@@ -447,7 +448,7 @@ void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
 
 #endif /* SHA2_UNROLL_TRANSFORM */
 
-void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
+void apr__SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
         unsigned int    freespace, usedspace;
 
         if (len == 0) {
@@ -458,7 +459,8 @@ void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
         /* Sanity check: */
         assert(context != (SHA256_CTX*)0 && data != (sha2_byte*)0);
 
-        usedspace = (context->bitcount >> 3) % SHA256_BLOCK_LENGTH;
+        usedspace = (unsigned int)((context->bitcount >> 3) 
+                                 % SHA256_BLOCK_LENGTH);
         if (usedspace > 0) {
                 /* Calculate how much free space is available in the buffer */
                 freespace = SHA256_BLOCK_LENGTH - usedspace;
@@ -469,7 +471,7 @@ void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
                         context->bitcount += freespace << 3;
                         len -= freespace;
                         data += freespace;
-                        SHA256_Transform(context, (sha2_word32*)context->buffer);
+                        apr__SHA256_Transform(context, (sha2_word32*)context->buffer);
                 } else {
                         /* The buffer is not yet full */
                         MEMCPY_BCOPY(&context->buffer[usedspace], data, len);
@@ -481,7 +483,7 @@ void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
         }
         while (len >= SHA256_BLOCK_LENGTH) {
                 /* Process as many complete blocks as we can */
-                SHA256_Transform(context, (sha2_word32*)data);
+                apr__SHA256_Transform(context, (sha2_word32*)data);
                 context->bitcount += SHA256_BLOCK_LENGTH << 3;
                 len -= SHA256_BLOCK_LENGTH;
                 data += SHA256_BLOCK_LENGTH;
@@ -495,7 +497,7 @@ void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
         usedspace = freespace = 0;
 }
 
-void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
+void apr__SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
         sha2_word32     *d = (sha2_word32*)digest;
         unsigned int    usedspace;
 
@@ -504,7 +506,8 @@ void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
 
         /* If no digest buffer is passed, we don't bother doing this: */
         if (digest != (sha2_byte*)0) {
-                usedspace = (context->bitcount >> 3) % SHA256_BLOCK_LENGTH;
+                usedspace = (unsigned int)((context->bitcount >> 3) 
+                                         % SHA256_BLOCK_LENGTH);
 #if !APR_IS_BIGENDIAN
                 /* Convert FROM host byte order */
                 REVERSE64(context->bitcount,context->bitcount);
@@ -521,7 +524,7 @@ void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
                                         MEMSET_BZERO(&context->buffer[usedspace], SHA256_BLOCK_LENGTH - usedspace);
                                 }
                                 /* Do second-to-last transform: */
-                                SHA256_Transform(context, (sha2_word32*)context->buffer);
+                                apr__SHA256_Transform(context, (sha2_word32*)context->buffer);
 
                                 /* And set-up for the last transform: */
                                 MEMSET_BZERO(context->buffer, SHA256_SHORT_BLOCK_LENGTH);
@@ -537,7 +540,7 @@ void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
                 *(sha2_word64*)&context->buffer[SHA256_SHORT_BLOCK_LENGTH] = context->bitcount;
 
                 /* Final transform: */
-                SHA256_Transform(context, (sha2_word32*)context->buffer);
+                apr__SHA256_Transform(context, (sha2_word32*)context->buffer);
 
 #if !APR_IS_BIGENDIAN
                 {
@@ -558,7 +561,7 @@ void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
         usedspace = 0;
 }
 
-char *SHA256_End(SHA256_CTX* context, char buffer[]) {
+char *apr__SHA256_End(SHA256_CTX* context, char buffer[]) {
         sha2_byte       digest[SHA256_DIGEST_LENGTH], *d = digest;
         int             i;
 
@@ -566,7 +569,7 @@ char *SHA256_End(SHA256_CTX* context, char buffer[]) {
         assert(context != (SHA256_CTX*)0);
 
         if (buffer != (char*)0) {
-                SHA256_Final(digest, context);
+                apr__SHA256_Final(digest, context);
 
                 for (i = 0; i < SHA256_DIGEST_LENGTH; i++) {
                         *buffer++ = sha2_hex_digits[(*d & 0xf0) >> 4];
@@ -581,17 +584,17 @@ char *SHA256_End(SHA256_CTX* context, char buffer[]) {
         return buffer;
 }
 
-char* SHA256_Data(const sha2_byte* data, size_t len, char digest[SHA256_DIGEST_STRING_LENGTH]) {
+char* apr__SHA256_Data(const sha2_byte* data, size_t len, char digest[SHA256_DIGEST_STRING_LENGTH]) {
         SHA256_CTX      context;
 
-        SHA256_Init(&context);
-        SHA256_Update(&context, data, len);
-        return SHA256_End(&context, digest);
+        apr__SHA256_Init(&context);
+        apr__SHA256_Update(&context, data, len);
+        return apr__SHA256_End(&context, digest);
 }
 
 
 /*** SHA-512: *********************************************************/
-void SHA512_Init(SHA512_CTX* context) {
+void apr__SHA512_Init(SHA512_CTX* context) {
         if (context == (SHA512_CTX*)0) {
                 return;
         }
@@ -636,7 +639,7 @@ void SHA512_Init(SHA512_CTX* context) {
         (h) = T1 + Sigma0_512(a) + Maj((a), (b), (c)); \
         j++
 
-void SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
+void apr__SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
         sha2_word64     a, b, c, d, e, f, g, h, s0, s1;
         sha2_word64     T1, *W512 = (sha2_word64*)context->buffer;
         int             j;
@@ -691,7 +694,7 @@ void SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
 
 #else /* SHA2_UNROLL_TRANSFORM */
 
-void SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
+void apr__SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
         sha2_word64     a, b, c, d, e, f, g, h, s0, s1;
         sha2_word64     T1, T2, *W512 = (sha2_word64*)context->buffer;
         int             j;
@@ -769,7 +772,7 @@ void SHA512_Transform(SHA512_CTX* context, const sha2_word64* data) {
 
 #endif /* SHA2_UNROLL_TRANSFORM */
 
-void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
+void apr__SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
         unsigned int    freespace, usedspace;
 
         if (len == 0) {
@@ -780,7 +783,8 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
         /* Sanity check: */
         assert(context != (SHA512_CTX*)0 && data != (sha2_byte*)0);
 
-        usedspace = (context->bitcount[0] >> 3) % SHA512_BLOCK_LENGTH;
+        usedspace = (unsigned int)((context->bitcount[0] >> 3) 
+                                 % SHA512_BLOCK_LENGTH);
         if (usedspace > 0) {
                 /* Calculate how much free space is available in the buffer */
                 freespace = SHA512_BLOCK_LENGTH - usedspace;
@@ -791,7 +795,7 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
                         ADDINC128(context->bitcount, freespace << 3);
                         len -= freespace;
                         data += freespace;
-                        SHA512_Transform(context, (sha2_word64*)context->buffer);
+                        apr__SHA512_Transform(context, (sha2_word64*)context->buffer);
                 } else {
                         /* The buffer is not yet full */
                         MEMCPY_BCOPY(&context->buffer[usedspace], data, len);
@@ -803,7 +807,7 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
         }
         while (len >= SHA512_BLOCK_LENGTH) {
                 /* Process as many complete blocks as we can */
-                SHA512_Transform(context, (sha2_word64*)data);
+                apr__SHA512_Transform(context, (sha2_word64*)data);
                 ADDINC128(context->bitcount, SHA512_BLOCK_LENGTH << 3);
                 len -= SHA512_BLOCK_LENGTH;
                 data += SHA512_BLOCK_LENGTH;
@@ -817,10 +821,11 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
         usedspace = freespace = 0;
 }
 
-void SHA512_Last(SHA512_CTX* context) {
+void apr__SHA512_Last(SHA512_CTX* context) {
         unsigned int    usedspace;
 
-        usedspace = (context->bitcount[0] >> 3) % SHA512_BLOCK_LENGTH;
+        usedspace = (unsigned int)((context->bitcount[0] >> 3) 
+                                 % SHA512_BLOCK_LENGTH);
 #if !APR_IS_BIGENDIAN
         /* Convert FROM host byte order */
         REVERSE64(context->bitcount[0],context->bitcount[0]);
@@ -838,7 +843,7 @@ void SHA512_Last(SHA512_CTX* context) {
                                 MEMSET_BZERO(&context->buffer[usedspace], SHA512_BLOCK_LENGTH - usedspace);
                         }
                         /* Do second-to-last transform: */
-                        SHA512_Transform(context, (sha2_word64*)context->buffer);
+                        apr__SHA512_Transform(context, (sha2_word64*)context->buffer);
 
                         /* And set-up for the last transform: */
                         MEMSET_BZERO(context->buffer, SHA512_BLOCK_LENGTH - 2);
@@ -855,10 +860,10 @@ void SHA512_Last(SHA512_CTX* context) {
         *(sha2_word64*)&context->buffer[SHA512_SHORT_BLOCK_LENGTH+8] = context->bitcount[0];
 
         /* Final transform: */
-        SHA512_Transform(context, (sha2_word64*)context->buffer);
+        apr__SHA512_Transform(context, (sha2_word64*)context->buffer);
 }
 
-void SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
+void apr__SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
         sha2_word64     *d = (sha2_word64*)digest;
 
         /* Sanity check: */
@@ -866,7 +871,7 @@ void SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
 
         /* If no digest buffer is passed, we don't bother doing this: */
         if (digest != (sha2_byte*)0) {
-                SHA512_Last(context);
+                apr__SHA512_Last(context);
 
                 /* Save the hash data for output: */
 #if !APR_IS_BIGENDIAN
@@ -887,7 +892,7 @@ void SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
         MEMSET_BZERO(context, sizeof(context));
 }
 
-char *SHA512_End(SHA512_CTX* context, char buffer[]) {
+char *apr__SHA512_End(SHA512_CTX* context, char buffer[]) {
         sha2_byte       digest[SHA512_DIGEST_LENGTH], *d = digest;
         int             i;
 
@@ -895,7 +900,7 @@ char *SHA512_End(SHA512_CTX* context, char buffer[]) {
         assert(context != (SHA512_CTX*)0);
 
         if (buffer != (char*)0) {
-                SHA512_Final(digest, context);
+                apr__SHA512_Final(digest, context);
 
                 for (i = 0; i < SHA512_DIGEST_LENGTH; i++) {
                         *buffer++ = sha2_hex_digits[(*d & 0xf0) >> 4];
@@ -910,17 +915,17 @@ char *SHA512_End(SHA512_CTX* context, char buffer[]) {
         return buffer;
 }
 
-char* SHA512_Data(const sha2_byte* data, size_t len, char digest[SHA512_DIGEST_STRING_LENGTH]) {
+char* apr__SHA512_Data(const sha2_byte* data, size_t len, char digest[SHA512_DIGEST_STRING_LENGTH]) {
         SHA512_CTX      context;
 
-        SHA512_Init(&context);
-        SHA512_Update(&context, data, len);
-        return SHA512_End(&context, digest);
+        apr__SHA512_Init(&context);
+        apr__SHA512_Update(&context, data, len);
+        return apr__SHA512_End(&context, digest);
 }
 
 
 /*** SHA-384: *********************************************************/
-void SHA384_Init(SHA384_CTX* context) {
+void apr__SHA384_Init(SHA384_CTX* context) {
         if (context == (SHA384_CTX*)0) {
                 return;
         }
@@ -929,11 +934,11 @@ void SHA384_Init(SHA384_CTX* context) {
         context->bitcount[0] = context->bitcount[1] = 0;
 }
 
-void SHA384_Update(SHA384_CTX* context, const sha2_byte* data, size_t len) {
-        SHA512_Update((SHA512_CTX*)context, data, len);
+void apr__SHA384_Update(SHA384_CTX* context, const sha2_byte* data, size_t len) {
+        apr__SHA512_Update((SHA512_CTX*)context, data, len);
 }
 
-void SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
+void apr__SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
         sha2_word64     *d = (sha2_word64*)digest;
 
         /* Sanity check: */
@@ -941,7 +946,7 @@ void SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
 
         /* If no digest buffer is passed, we don't bother doing this: */
         if (digest != (sha2_byte*)0) {
-                SHA512_Last((SHA512_CTX*)context);
+                apr__SHA512_Last((SHA512_CTX*)context);
 
                 /* Save the hash data for output: */
 #if !APR_IS_BIGENDIAN
@@ -962,7 +967,7 @@ void SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
         MEMSET_BZERO(context, sizeof(context));
 }
 
-char *SHA384_End(SHA384_CTX* context, char buffer[]) {
+char *apr__SHA384_End(SHA384_CTX* context, char buffer[]) {
         sha2_byte       digest[SHA384_DIGEST_LENGTH], *d = digest;
         int             i;
 
@@ -970,7 +975,7 @@ char *SHA384_End(SHA384_CTX* context, char buffer[]) {
         assert(context != (SHA384_CTX*)0);
 
         if (buffer != (char*)0) {
-                SHA384_Final(digest, context);
+                apr__SHA384_Final(digest, context);
 
                 for (i = 0; i < SHA384_DIGEST_LENGTH; i++) {
                         *buffer++ = sha2_hex_digits[(*d & 0xf0) >> 4];
@@ -985,11 +990,11 @@ char *SHA384_End(SHA384_CTX* context, char buffer[]) {
         return buffer;
 }
 
-char* SHA384_Data(const sha2_byte* data, size_t len, char digest[SHA384_DIGEST_STRING_LENGTH]) {
+char* apr__SHA384_Data(const sha2_byte* data, size_t len, char digest[SHA384_DIGEST_STRING_LENGTH]) {
         SHA384_CTX      context;
 
-        SHA384_Init(&context);
-        SHA384_Update(&context, data, len);
-        return SHA384_End(&context, digest);
+        apr__SHA384_Init(&context);
+        apr__SHA384_Update(&context, data, len);
+        return apr__SHA384_End(&context, digest);
 }
 
