@@ -1,9 +1,9 @@
-/* Copyright 2000-2005 The Apache Software Foundation or its licensors, as
- * applicable.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -714,7 +714,7 @@ APR_DECLARE(void) apr_table_mergen(apr_table_t *t, const char *key,
 	    abort();
 	}
 	if (!apr_pool_is_ancestor(apr_pool_find(val), t->a.pool)) {
-	    fprintf(stderr, "apr_table_mergen: key not in ancestor pool of t\n");
+	    fprintf(stderr, "apr_table_mergen: val not in ancestor pool of t\n");
 	    abort();
 	}
     }
@@ -783,7 +783,7 @@ APR_DECLARE(void) apr_table_addn(apr_table_t *t, const char *key,
 	    abort();
 	}
 	if (!apr_pool_is_ancestor(apr_pool_find(val), t->a.pool)) {
-	    fprintf(stderr, "apr_table_addn: key not in ancestor pool of t\n");
+	    fprintf(stderr, "apr_table_addn: val not in ancestor pool of t\n");
 	    abort();
 	}
     }
